Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(210)

Unified Diff: ui/aura/window_event_dispatcher.cc

Issue 1907323003: Drag and drop cleans up touch sequences from the source window. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix another test. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/aura/window_event_dispatcher.cc
diff --git a/ui/aura/window_event_dispatcher.cc b/ui/aura/window_event_dispatcher.cc
index d34ad330b94132a61b11b0bb623da676b972620a..53f20e23c4f0ec6a9ef5e0170c5f15e48123808d 100644
--- a/ui/aura/window_event_dispatcher.cc
+++ b/ui/aura/window_event_dispatcher.cc
@@ -528,10 +528,8 @@ bool WindowEventDispatcher::CanDispatchToConsumer(
return (consumer_window && consumer_window->GetRootWindow() == window());
}
-void WindowEventDispatcher::DispatchCancelTouchEvent(
- ui::GestureConsumer* raw_input_consumer,
- ui::TouchEvent* event) {
- // The touchcancel event's location is based on the last known location of
+void WindowEventDispatcher::DispatchSyntheticTouchEvent(ui::TouchEvent* event) {
+ // The synthetic event's location is based on the last known location of
// the pointer, in dips. OnEventFromSource expects events with co-ordinates
// in raw pixels, so we convert back to raw pixels here.
event->UpdateForRootTransform(host_->GetRootTransform());

Powered by Google App Engine
This is Rietveld 408576698